#pylint:disable=C0111

__title__ = 'geoip2'
__version__ = '0.1.1'
__author__ = 'Gregory Oschwald'
__license__ = 'LGPLv2+'
__copyright__ = 'Copyright 2013 Maxmind, Inc.'
